
import Layout from "@/components/Layout";
import SEOHead from "@/components/SEOHead";
import { ArrowRight } from "lucide-react";
import { Link } from "react-router-dom";
import { Button } from "@/components/ui/button";

const Index = () => {
  return (
    <Layout>
      <SEOHead
        title="Risveglio Ancestrale – Nutrizione Evolutiva & Verità Scomode"
        description="Il blog indipendente che demolisce i dogmi nutrizionali e scientifici: alimentazione ancestrale, salute evolutiva, biochimica e fisiologia umana. Leggi articoli veri, senza compromessi."
        keywords={[
          "nutrizione ancestrale",
          "alimentazione evolutiva",
          "salute evolutiva",
          "biochimica umana",
          "carnivora",
          "dogmi nutrizionali",
          "verità scientifiche"
        ]}
        canonicalUrl="https://www.risveglioancestrale.it"
        type="website"
      />
      
      {/* Hero Section - ABOVE THE FOLD */}
      <section className="relative bg-nero text-beige py-20 md:py-32">
        <div className="absolute inset-0 bg-[url('https://images.unsplash.com/photo-1472396961693-142e6e269027?q=80&w=1000')] bg-cover bg-center opacity-20"></div>
        <div className="container-custom relative z-10">
          <div className="max-w-4xl mx-auto text-center">
            <h1 className="text-lg sm:text-xl md:text-2xl lg:text-3xl mb-4 fadeInUp leading-snug sm:leading-tight break-words max-w-prose mx-auto text-beige/90 text-center">
              E SE LA TUA STANCHEZZA COSTANTE, IL GRASSO OSTINATO E I SINTOMI CRONICI CHE TI ATTANAGLIANO...
              <span className="block mt-2 text-[1.4em] sm:text-[1.5em] md:text-[1.6em] lg:text-[1.75em] leading-[1.1] break-words">
                FOSSERO CAUSATI DAL <u>SEGUIRE DILIGENTEMENTE</u> LA <span className="text-red-500">PIRAMIDE ALIMENTARE</span>?
              </span>
            </h1>
            <p className="text-sm sm:text-base md:text-lg lg:text-xl mb-12 fadeInUp leading-normal sm:leading-relaxed break-words max-w-prose mx-auto" style={{ animationDelay: "0.2s" }}>
              Nel blog indipendente <em className="font-semibold">Risveglio Ancestrale</em> disseziono i dogmi e le concezioni della "Scienza" ufficiale, 
              guidandoti verso l'unica alimentazione che rispetta davvero la tua fisiologia e i tuoi processi metabolici.
            </p>
            
            {/* Primary CTA - Above the fold */}
            <Link 
              to="/blog" 
              className="inline-block fadeInUp" 
              style={{ animationDelay: "0.3s" }}
            >
              <Button 
                variant="default" 
                size="lg" 
                className="bg-oro text-nero hover:bg-transparent hover:text-oro border-2 border-oro text-base sm:text-lg px-6 sm:px-8 py-4 sm:py-6 h-auto"
              >
                Inizia ORA il tuo risveglio <ArrowRight className="ml-2" />
              </Button>
            </Link>
          </div>
        </div>
      </section>

      {/* Lettera Aperta Section - BELOW THE FOLD */}
      <section id="lettera" className="py-16 md:py-24 bg-beige">
        <div className="container-custom">
          <div className="max-w-4xl mx-auto">
            <h2 className="section-title text-3xl md:text-4xl mb-12 text-porpora text-center">
              ATTENZIONE: QUESTO SITO POTREBBE NON ESSERE ADATTO A TE.
            </h2>
            <div className="prose prose-lg mx-auto text-left">
              <p className="text-lg mb-6">
                <strong>Caro lettore,</strong>
              </p>
              
              <p className="text-lg mb-6">
                Ti scrivo questa breve lettera appena dopo aver mangiato una <strong>succulenta bistecca al sangue</strong> (sì, una di quelle cancerogene)
              </p>
              
              <p className="text-lg mb-6">
                Quindi sì, mi ritengo decisamente di buon umore.
              </p>
              
              <p className="text-lg mb-6">
                Inoltre, se è la prima volta che incroci le mie parole, forse dovrei accoglierti con dolcezza, con gentilezza e persino con una certa accondiscendenza.
              </p>
              
              <p className="text-lg mb-6">
                Ma la verità è che <strong>non ne ho alcuna intenzione.</strong>
              </p>
              
              <p className="text-lg mb-6">
                Anzi, preferisco parlare fin da subito in modo <strong>chiaro</strong> e <strong>diretto</strong>.
              </p>
              
              <p className="text-lg mb-6">
                Senza giri di parole né inutili pacche sulle spalle che non ti porteranno da nessuna parte.
              </p>
              
              <h3 className="text-2xl font-bold my-8 text-nero uppercase">
                SE PENSI CHE QUESTO SIA L'ENNESIMO SITO IN CUI SI PARLA…
              </h3>
              
              <ul className="list-disc pl-5 text-lg mb-6">
                <li>Di quanto il <strong>Colesterolo</strong> sia brutto e cattivo</li>
                <li>Di quanto mangiare prodotti (e proteine) animali mandi a puttane la tua longevità</li>
                <li>O di quanto la carne rossa (o addirittura quella lavorata) sia cancerogena.</li>
              </ul>
              
              <p className="text-lg mb-6">
                Allora ti chiedo la cortesia di <strong>interrompere la lettura qui e di uscire</strong>.
              </p>

              <p className="text-lg mb-6">
                Risparmieremo tempo entrambi.
              </p>

              <p className="text-lg mb-6">
                Ma se invece ti trovi qui…
              </p>
                           
              <p className="text-lg mb-6">
                Nella speranza di non venire più strattonato qua e là da continue opinioni contrastanti che invece di aiutarti non fanno altro che aumentare la tua confusione
              </p>
              
              <p className="text-lg mb-6">
                Con l'obiettivo di capire finalmente <strong>come mai le forze abbiano improvvisamente iniziato ad abbandonarti</strong> (e ovviamente come puoi rimetterti in carreggiata arrivando quasi a vivere una seconda giovinezza).
              </p>
              
              <p className="text-lg mb-6">
                Perché non ne puoi più dei soliti commenti <em>"Eh, ma con l'età che avanza è normale"</em>
              </p>
              
              <p className="text-lg mb-6">
                Allora ti dò il mio caloroso benvenuto nel Blog indipendente <strong>RISVEGLIO ANCESTRALE</strong>.
              </p>
              
              <h3 className="text-2xl font-bold my-8 text-nero uppercase">
                CHI SONO IO PER PARLARTI DI QUESTO E COSA POSSO FARE PER TE
              </h3>
              
              <p className="text-lg mb-6">
                Sono l'Ing. Luigi Calandri e sono un <strong>Carnivore Coach</strong>. La mia missione è aiutare uomini e donne Over-40 a riacquistare <strong>IL VIGORE</strong>, <strong>L'ENERGIA</strong> e la <strong>LUCIDITÀ</strong> della propria gioventù grazie ad un approccio sistematico e studiato passo-passo che ho definito <strong>RESET ANCESTRALE</strong>.
              </p>
              
              <p className="text-lg mb-6">
                L'obiettivo di questo Blog e dei miei percorsi personalizzati, è quello di renderti un essere pensante e totalmente <strong>INDIPENDENTE</strong> per quanto riguarda la tua alimentazione.
              </p>
              
              <p className="text-lg mb-6">
                Ciò a cui punto <strong>non</strong> è una semplice dieta che smetti in Inverno ed inizi nuovamente in vista dell'Estate…
              </p>

              <p className="text-lg mb-6">
                …Durante la quale, tra un'insalata scondita e l'altra, non aspetti altro che la pizza del weekend…
              </p>
              
              <p className="text-lg mb-6">
                <strong>Assolutamente no.</strong>
              </p>
              
              <p className="text-lg mb-6">
                Ciò a cui punto è un vero e proprio <strong>cambio di paradigma</strong>, una tua evoluzione in quanto persona e soprattutto del tuo rapporto con il cibo.
              </p>
              
              <p className="text-lg mb-6 italic">
                (vuoi conoscere la mia storia? Vai alla sezione "Chi sono" presente in alto a destra)
              </p>
              
              <h3 className="text-2xl font-bold my-8 text-nero uppercase">
                PENSI SIA NORMALE CHE 9 NUTRIZIONISTI SU 10 RIPETANO A MEMORIA LE SOLITE LINEE GUIDA SENZA AVER MAI NEMMENO PROVATO A LEGGERE LE EVIDENZE "SCIENTIFICHE" CHE LE HANNO ISPIRATE?
              </h3>
                         
              <p className="text-lg mb-6">
                Per carità…
              </p>

              <p className="text-lg mb-6">
                Non gli è stato insegnato come farlo…
              </p>

              <p className="text-lg mb-6">
                E soprattutto, non gli è mai stata trasmessa l'importanza di uno spirito critico dal punto di vista scientifico…
              </p>

              <p className="text-lg mb-6">
                Tuttavia perdonami…
              </p>
              
              <p className="text-lg mb-6">
                <strong>A tutto c'è un limite.</strong>
              </p>
              
              <p className="text-lg mb-6">
                La pigrizia del non volersi aggiornare…
              </p>

              <p className="text-lg mb-6">
                Il sentirsi arrivati dopo un semplice pezzo di carta (e quel pezzo di carta ce l'ho anche io, quindi so di che parlo)
              </p>

              <p className="text-lg mb-6">
                Il difendere ciecamente e a spada tratta concetti non solo antiquati, ma anche largamente <strong>CONFUTATI</strong>.
              </p>

              <p className="text-lg mb-6">
                Il prescrivere dei piani alimentari omologati che assomigliano più alla simulazione di una carestia post-apocalittica che ad uno stile di vita a cui ambire
              </p>

              <p className="text-lg mb-6">
                Ma soprattutto…
              </p>
              
              <p className="text-lg mb-6">
                <strong>IL PATETICO APPELLO ALL'AUTORITÀ</strong>
              </p>
              
              <p className="text-lg mb-6">
                Alle reputate intoccabili "Linee Guida" che, come è evidente, hanno permesso alla nostra società di essere sempre più in salute…
              </p>

              <p className="text-lg mb-6">
                (nel caso non si notasse, sono sarcastico)
              </p>
              
              <p className="text-lg mb-6">
                Per tutto questo, non penso ci siano scuse.
              </p>

              <p className="text-lg mb-6">
                Prendimi per pazzo ma io credo che, con le dovute limitazioni e proporzioni, il mestiere di nutrizionista comporti le stesse responsabilità di un medico.
              </p>

              <p className="text-lg mb-6">
                Per capirci meglio, nella MIA visione:
              </p>
              
              <p className="text-lg mb-6">
                <strong>IL NUTRIZIONISTA STA ALLA PREVENZIONE COME IL MEDICO STA ALLA CURA.</strong>
              </p>
              
              <p className="text-lg mb-6">
                Perché che tu ci creda o meno, il cibo può essere medicina o veleno.
              </p>
              
              <p className="text-lg mb-6">
                E anche all'interno di un piano alimentare che può sembrare sensato, "bilanciato" o altri termini che piacciono molto, possono nascondersi molte insidie.
              </p>

              <p className="text-lg mb-6">
                Detto questo..
              </p>
              
              <h3 className="text-2xl font-bold my-8 text-nero uppercase">
                Ora ti trovi davanti ad un BIVIO
              </h3>
              
              <p className="text-lg mb-6">
                Puoi cercare le informazioni per conto tuo.
              </p>
              
              <p className="text-lg mb-6">
                Fattibile eh, per carità.
              </p>

              <p className="text-lg mb-6">
                Devi solo essere consapevole di dover dedicare ad ogni argomento indefinite ore del tuo tempo, partendo prima di tutto dalle basi e con il rischio estremamente alto di <strong>sovraccarico cognitivo</strong> (in altre parole, il tuo cervello va in palla per la quantità eccessiva di informazioni).
              </p>
              
              <p className="text-lg mb-6">
                Puoi leggere ogni singolo articolo di questo blog come fosse il più importante della tua vita e <strong>risparmiarti molte pene e, soprattutto, tempo prezioso</strong>.
              </p>
              
              <h3 className="text-2xl font-bold my-8 text-nero uppercase">
                VOGLIO FARTI UNA SEMPLICE MA SOLENNE PROMESSA
              </h3>
              
              <p className="text-lg mb-6">
                Se sceglierai di affidarti a questo blog, sappi questo:
              </p>
              
              <p className="text-lg mb-6">
                <strong>Le informazioni che ti fornirò all'interno dei preziosi articoli rappresenteranno un punto di svolta nella tua vita.</strong>
              </p>
              
              <p className="text-lg mb-6">
                Perché così è stato (ed è tutt'ora, dal momento che sono in continuo apprendimento) anche per me.
              </p>
              
              <p className="text-lg mb-6">
                E dopo che avrai <strong>scoperchiato il Vaso di Pandora</strong> e avrai capito quanto ti è stato nascosto e quante energie e tempo crudelmente sottratti…
              </p>

              <p className="text-lg mb-6">
                <strong>Non sarai più la stessa persona.</strong>
              </p>
              
              <p className="text-lg mt-10 mb-8">
                <strong>Buon Risveglio.</strong><br /><br />Luigi
              </p>
              
              {/* Final CTA Button */}
              <div className="text-center my-12">
                <Link to="/blog">
                  <Button 
                    variant="default" 
                    size="lg" 
                    className="bg-porpora text-beige hover:bg-transparent hover:text-porpora border-2 border-porpora text-lg px-8 py-6 h-auto"
                  >
                    Parti da qui per iniziare il tuo risveglio <ArrowRight className="ml-2" />
                  </Button>
                </Link>
              </div>
            </div>
          </div>
        </div>
      </section>
    </Layout>
  );
};

export default Index;
